@@ -4,14 +4,14 @@ export class CrossrefSearcher {
 
     constructor(importer) {
         this.importer = importer
-        this.id = 'crossref'
-        this.name = 'Crossref'
+        this.id = "crossref"
+        this.name = "Crossref"
     }
 
     bind() {
-        document.querySelectorAll('#bibimport-search-result-crossref .api-import').forEach(resultEl => {
+        document.querySelectorAll("#bibimport-search-result-crossref .api-import").forEach(resultEl => {
             const doi = resultEl.dataset.doi
-            resultEl.addEventListener('click', () => this.getBibtex(doi))
+            resultEl.addEventListener("click", () => this.getBibtex(doi))
         })
     }
 
@@ -21,7 +21,7 @@ export class CrossrefSearcher {
         }).then(
             response => response.json()
         ).then(items => {
-            const searchEl = document.getElementById('bibimport-search-result-crossref')
+            const searchEl = document.getElementById("bibimport-search-result-crossref")
             if (!searchEl) {
                 // window was closed before result was ready.
                 return
@@ -29,7 +29,7 @@ export class CrossrefSearcher {
             if (items.length) {
                 searchEl.innerHTML = searchApiResultCrossrefTemplate({items})
             } else {
-                searchEl.innerHTML = ''
+                searchEl.innerHTML = ""
             }
             this.bind()
         })
@@ -37,8 +37,11 @@ export class CrossrefSearcher {
 
     getBibtex(doi) {
         this.importer.dialog.close()
-        fetch(`https://search.crossref.org/citation?format=bibtex&doi=${doi}`, {
-            method: "GET"
+        fetch(`https://api.crossref.org/v1/works/${doi}/transform`, {
+            method: "GET",
+            headers: {
+                "Accept": "application/x-bibtex"
+            }
         }).then(
             response => response.text()
         ).then(
