@@ -57,7 +57,7 @@ export class GesisSearcher {
             }
         }
 
-        return fetch(`https://search.gesis.org/searchengine?source=${encodeURI(JSON.stringify(searchQuery))}`, {
+        return fetch(`https://search.gesis.org/searchengine?source=${encodeURI(JSON.stringify(searchQuery))}&source_content_type=${encodeURI("application/json")}`, {
             method: "GET"
         }).then(
             response => response.json()
@@ -82,11 +82,12 @@ export class GesisSearcher {
     getBibtex(id, type) {
         this.importer.dialog.close()
         get(
-            "/proxy/citation_api_import/https://search.gesis.org/ajax/bibtex.php",
+            "/api/citation_api_import/proxy/https://search.gesis.org/ajax/bibtex.php",
             {
                 type,
                 docid: id,
-                download: "true"
+                download: "true",
+                searchengine_mode: "ES8"
             }
         ).then(
             response => response.text()
