@@ -4,33 +4,33 @@ export const searchApiTemplate = ({searchers}) =>
     `<p>
         <input id="bibimport-search-text" class="linktitle" type="text" value=""
                 placeholder="${gettext("Title, Author, DOI, etc.")}"><br>
-        ${searchers.map(searcher => `<input type="checkbox" class="bibimport-search-enabled" id="bibimport-enable-${searcher.id}">&nbsp;${escapeText(searcher.name)}`).join(' ')}
+        ${searchers.map(searcher => `<input type="checkbox" class="bibimport-search-enabled" id="bibimport-enable-${searcher.id}">&nbsp;${escapeText(searcher.name)}`).join(" ")}
         <button id="bibimport-search-button" class="fw-button fw-dark" type="button">
             ${gettext("search")}
         </button>
     </p>
     <div id="bibimport-search-header"></div>
-    ${searchers.map(searcher => `<div id="bibimport-search-result-${searcher.id}" class="bibimport-search-result"></div>`).join('')}`
+    ${searchers.map(searcher => `<div id="bibimport-search-result-${searcher.id}" class="bibimport-search-result"></div>`).join("")}`
 
 export const searchApiResultGesisTemplate = ({items}) => {
-    return '<h3 class="fw-green-title">GESIS Search</h3><table class="fw-data-table fw-large dataTable-table">' +
+    return "<h3 class=\"fw-green-title\">GESIS Search</h3><table class=\"fw-data-table fw-large dataTable-table\">" +
         `<tr>
             <th></th>
-            <th>${gettext('Title')}</th>
-            <th>${gettext('Author(s)')}</th>
-            <th>${gettext('Published')}</th>
-            <th>${gettext('Abstract')}</th>
+            <th>${gettext("Title")}</th>
+            <th>${gettext("Author(s)")}</th>
+            <th>${gettext("Published")}</th>
+            <th>${gettext("Abstract")}</th>
         </tr>` +
         items.map(item => {
-            const itemTitle = item.title ? typeof item.title === 'object' ? item.title[0] : item.title : false
-            const itemAbstract = item.abstract ? typeof item.abstract === 'object' ? item.abstract[0] : item.abstract : false
+            const itemTitle = item.title ? typeof item.title === "object" ? item.title[0] : item.title : false
+            const itemAbstract = item.abstract ? typeof item.abstract === "object" ? item.abstract[0] : item.abstract : false
             return `<tr class="item">
                 <td><button type="button"
                         class="api-import fw-button fw-orange fw-small"
                         data-id="${item.id}"
                         data-type="${item.type}"
                 >
-                    ${gettext('Import')}
+                    ${gettext("Import")}
                 </button></td>
                 <td>
                 ${
@@ -38,7 +38,7 @@ export const searchApiResultGesisTemplate = ({items}) => {
         `<h3>
                         ${escapeText(itemTitle)}
                     </h3>` :
-        ''
+        ""
 }
                 </td>
                 <td>
@@ -47,14 +47,14 @@ export const searchApiResultGesisTemplate = ({items}) => {
         `<p>
                         ${item.person.join("; ")}
                     </p>` :
-        ''
+        ""
 }
                 </td>
                 <td>
                 ${
     item.date ?
         `<p>${item.date}</p>` :
-        ''
+        ""
 }
                 </td>
                 <td>
@@ -67,28 +67,28 @@ export const searchApiResultGesisTemplate = ({items}) => {
         escapeText(itemAbstract.substring(0, 200)) + "..."
 }
                     </p>` :
-        ''
+        ""
 }
                 </td>
             </tr>`
-        }).join('') + '</table>'
+        }).join("") + "</table>"
 }
 
 export const searchApiResultDataciteTemplate = ({items}) => {
-    return '<h3 class="fw-green-title">Datacite</h3><table class="fw-data-table fw-large dataTable-table">' +
+    return "<h3 class=\"fw-green-title\">Datacite</h3><table class=\"fw-data-table fw-large dataTable-table\">" +
         `<tr>
             <th></th>
-            <th>${gettext('Title')}</th>
-            <th>${gettext('Author(s)')}</th>
-            <th>${gettext('Published')}</th>
-            <th>${gettext('DOI')}</th>
-            <th>${gettext('Description')}</th>
+            <th>${gettext("Title")}</th>
+            <th>${gettext("Author(s)")}</th>
+            <th>${gettext("Published")}</th>
+            <th>${gettext("DOI")}</th>
+            <th>${gettext("Description")}</th>
         </tr>` +
         items.map(item =>
             `<tr class="item">
                 <td><button type="button" class="api-import fw-button fw-orange fw-small"
                         data-doi="${item.doi}">
-                    ${gettext('Import')}
+                    ${gettext("Import")}
                 </button></td>
                 <td><h3>
                     ${escapeText(item.title)}
@@ -105,21 +105,21 @@ export const searchApiResultDataciteTemplate = ({items}) => {
     ).join(", ")
 }
                     </p>` :
-        ''
+        ""
 }
                 </td>
                 <td>
                 ${
     item.published ?
         `<p>${item.published}</p>` :
-        ''
+        ""
 }
                 </td>
                 <td>
                 ${
     item.doi ?
         `<p>${item.doi}</p>` :
-        ''
+        ""
 }
                 </td>
                 <td>
@@ -132,28 +132,28 @@ export const searchApiResultDataciteTemplate = ({items}) => {
         escapeText(item.description.substring(0, 200)) + "..."
 }
                     </p>` :
-        ''
+        ""
 }
                 </td>
             </tr>`
-        ).join('') + '</table>'
+        ).join("") + "</table>"
 }
 
 
 export const searchApiResultPubmedTemplate = ({items}) => {
-    return '<h3 class="fw-green-title">Pubmed</h3><table class="fw-data-table fw-large dataTable-table">' +
+    return "<h3 class=\"fw-green-title\">Pubmed</h3><table class=\"fw-data-table fw-large dataTable-table\">" +
         `<tr>
             <th></th>
-            <th>${gettext('Title')}</th>
-            <th>${gettext('Author(s)')}</th>
-            <th>${gettext('Published')}</th>
-            <th>${gettext('PMID')}</th>
+            <th>${gettext("Title")}</th>
+            <th>${gettext("Author(s)")}</th>
+            <th>${gettext("Published")}</th>
+            <th>${gettext("PMID")}</th>
         </tr>` +
         items.map(item =>
             `<tr class="item">
                 <td><button type="button" class="api-import fw-button fw-orange fw-small"
                         data-pmid="${item.pmid}">
-                    ${gettext('Import')}
+                    ${gettext("Import")}
                 </button></td>
                 <td><h3>
                     ${item.title}
@@ -168,23 +168,23 @@ export const searchApiResultPubmedTemplate = ({items}) => {
                     <p>${item.pmid}</p>
                 </td>
             </tr>`
-        ).join('') + '</table>'
+        ).join("") + "</table>"
 }
 
 
 export const searchApiResultCrossrefTemplate = ({items}) => {
-    return '<h3 class="fw-green-title">Crossref</h3><table class="fw-data-table fw-large dataTable-table">' +
+    return "<h3 class=\"fw-green-title\">Crossref</h3><table class=\"fw-data-table fw-large dataTable-table\">" +
         `<tr>
             <th></th>
-            <th>${gettext('Title/Year')}</th>
-            <th>${gettext('DOI')}</th>
-            <th>${gettext('Description')}</th>
+            <th>${gettext("Title/Year")}</th>
+            <th>${gettext("DOI")}</th>
+            <th>${gettext("Description")}</th>
         </tr>` +
         items.map(item =>
             `<tr class="item">
                 <td><button type="button" class="api-import fw-button fw-orange fw-small"
-                        data-doi="${item.doi.replace(/https?:\/\/(dx\.)?doi\.org\//gi, '')}">
-                    ${gettext('Import')}
+                        data-doi="${item.doi.replace(/https?:\/\/(dx\.)?doi\.org\//gi, "")}">
+                    ${gettext("Import")}
                 </button></td>
                 <td><h3>
                     ${
@@ -197,7 +197,7 @@ export const searchApiResultCrossrefTemplate = ({items}) => {
                 ${
     item.doi ?
         `<p>${item.doi}</p>` :
-        ''
+        ""
 }
                 </td>
                 <td>
@@ -210,9 +210,9 @@ export const searchApiResultCrossrefTemplate = ({items}) => {
         escapeText(item.description.substring(0, 200)) + "..."
 }
                     </p>` :
-        ''
+        ""
 }
                 </td>
             </tr>`
-        ).join('') + '</table>'
+        ).join("") + "</table>"
 }
